@@ -105,8 +105,7 @@ class RudderstackSink(Sink):
             )
             logging.debug(f'Element: {serialized_data} tracked.')
         except Exception as e:
-            logging.error(f'Exception occured in RudderstackSink `push`: {e}')
-            raise e
+            logging.warning(f'Exception occured in RudderstackSink `push`: {e}')
 
         return True
 
